..\pagecatcher.py exec example1_fillform.py
..\pagecatcher.py exec example2_reverse.py
..\pagecatcher.py exec example3_append.py
..\pagecatcher.py exec example4_fourpage.py
..\pagecatcher.py exec example5_background.py
..\pagecatcher.py exec example6_twopage.py
..\pagecatcher.py exec example7_split.py
